"""
do you know the golden rules of a successful data vizulisation? this library helps users to ensure their data viz communicate the information as clearly and neutrally as possible, while respecting a set of Golden Rules.
"""

__version__ = "0.0.1"
